@@ -11,7 +11,8 @@ class QQREncode
     Q_ENUMS(ErrorCorrectionLevel)
 
 public:
-    enum ErrorCorrectionLevel {
+    enum ErrorCorrectionLevel
+    {
         LOW,
         MEDIUM,
         QUARTILE,
@@ -33,10 +34,10 @@ public:
     void setForeground(QColor color);
 
     bool encode(QByteArray input);
-    bool encode(QString input, bool caseSensitive=true);
-    bool encodeKanji(QByteArray input, bool caseSensitive=true);
+    bool encode(QString input, bool caseSensitive = true);
+    bool encodeKanji(QByteArray input, bool caseSensitive = true);
 
-    QImage toQImage(int size=0);
+    QImage toQImage(int size = 0);
 
     // ToDo: encode structured, rle
 
