@@ -1,13 +1,19 @@
+/*
+    SPDX-FileCopyrightText: 2021 barcoder team <dpkg@chris-nz.com>
+
+    SPDX-License-Identifier: MIT
+*/
 #ifndef MAINWINDOW_H
 #define MAINWINDOW_H
 
 #include <QMainWindow>
 
-namespace Ui {
+namespace Ui
+{
 class MainWindow;
 }
 
-class MainWindow : public QMainWindow
+class MainWindow: public QMainWindow
 {
     Q_OBJECT
 
